@@ -6,7 +6,7 @@ typedef struct _E_Obj_Dialog E_Theme_About;
 #ifndef E_THEME_ABOUT_H
 #define E_THEME_ABOUT_H
 
-E_API E_Theme_About  *e_theme_about_new  (E_Comp *c);
+E_API E_Theme_About  *e_theme_about_new  (void);
 E_API void            e_theme_about_show (E_Theme_About *about);
 
 #endif
